@@ -28,5 +28,7 @@ keys in the dictionary are recognized, most are optional:
                 if a directory is contained, must be the same for all targets
 """
 
-__version__ = "0.3.1"
-import py2app.install
+__version__ = "0.3.3"
+
+# This makes the py2app command work in the distutils.core.setup() case
+import setuptools
